package com.ruoyi.frequency.rechargerecord.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.frequency.rechargerecord.entity.RechargeRecord;

import java.util.List;

/**
 * 充值记录Mapper接口
 * 
 * @author liwenlong
 * @date 2023-10-25
 */
public interface RechargeRecordMapper  extends BaseMapper<RechargeRecord>
{
    /**
     * 查询充值记录
     * 
     * @param id 充值记录主键
     * @return 充值记录
     */
    public RechargeRecord selectRechargeRecordById(Long id);

    /**
     * 查询充值记录列表
     * 
     * @param rechargeRecord 充值记录
     * @return 充值记录集合
     */
    public List<RechargeRecord> selectRechargeRecordList(RechargeRecord rechargeRecord);

    /**
     * 新增充值记录
     * 
     * @param rechargeRecord 充值记录
     * @return 结果
     */
    public int insertRechargeRecord(RechargeRecord rechargeRecord);

    /**
     * 修改充值记录
     * 
     * @param rechargeRecord 充值记录
     * @return 结果
     */
    public int updateRechargeRecord(RechargeRecord rechargeRecord);

    /**
     * 删除充值记录
     * 
     * @param id 充值记录主键
     * @return 结果
     */
    public int deleteRechargeRecordById(Long id);

    /**
     * 批量删除充值记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRechargeRecordByIds(Long[] ids);
}
